@@ -60,7 +60,8 @@ def omniModel(path, pathUnlabelled,learners,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
-    for image in images:
+    print("Processing unlabeled images")
+    for image in tqdm(images,position=0, leave=True):
         lista=[]
         for learn in learners:
             p=learn.predict(image)
@@ -81,8 +82,8 @@ def omniData(path, pathUnlabelled,learn, transforms,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
-
-    for image in images:
+    print("Processing unlabeled images")
+    for image in tqdm(images,position=0, leave=True):
         im = cv2.imread(image, 1)
         im = cv2.cvtColor(im, cv2.COLOR_BGR2RGB)
         lista = []
@@ -114,7 +115,8 @@ def omniModelData(path, pathUnlabelled,learners,transforms,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
-    for image in images:
+    print("Processing unlabeled images")
+    for image in tqdm(images,position=0, leave=True):
         lista=[]
         for learn in learners:
             im=cv2.imread(image,1)
@@ -144,6 +146,7 @@ def plainSupervised(path,pathUnlabelled,learn,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
+    print("Processing unlabeled images")
     for image in tqdm(images,position=0, leave=True):
         pn=learn.predict(image)
         if pn[2][pn[2].argmax()]>th:
